@@ -22,6 +22,8 @@
 #ifndef NETK_WINDOW_MENU_H
 #define NETK_WINDOW_MENU_H
 
+#if defined(LIBXFCEGUI4_COMPILATION) || !defined(XFCE_DISABLE_DEPRECATED)
+
 #include <libxfcegui4/netk-window.h>
 #include <gtk/gtk.h>
 
@@ -30,4 +32,7 @@ G_BEGIN_DECLS
 GtkWidget *netk_create_window_menu (GList * windows);
 
 G_END_DECLS
+
+#endif /* !XFCE_DISABLE_DEPRECATED */
+
 #endif /* NETK_WINDOW_MENU_H */
